function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactGridLayout = require('react-grid-layout');
var button = require('primereact/button');
var overlaypanel = require('primereact/overlaypanel');
var progressspinner = require('primereact/progressspinner');
var axios = _interopDefault(require('axios'));
var tooltip = require('primereact/tooltip');
var ReactFC = _interopDefault(require('react-fusioncharts'));
var FusionCharts = _interopDefault(require('fusioncharts'));
var Charts = _interopDefault(require('fusioncharts/fusioncharts.charts'));
var FusionTheme = _interopDefault(require('fusioncharts/themes/fusioncharts.theme.fusion'));
var useResizeObserver = _interopDefault(require('use-resize-observer'));

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var Tools = /*#__PURE__*/function () {
  function Tools() {}

  Tools.GetLogitudeURL = function GetLogitudeURL() {
    var logitude_url = location.href.replace('index.html', '');

    if (location.href.indexOf('localhost') > -1) {
      logitude_url = 'http://localhost:9996';
    } else {
      var urlArr = location.href.split("/index.html");
      var url = urlArr[0];
      url = url.replace(url.substring(url.lastIndexOf('/'), url.length), "");
      logitude_url = url;
    }

    return logitude_url;
  };

  Tools.Map = function Map(from, to) {
    if (!from) return;
    if (!to) to = {};
    var keys = Object.keys(from);

    for (var _i = 0, _keys = keys; _i < _keys.length; _i++) {
      var k = _keys[_i];

      if (from[k]) {
        to[k] = from[k];
      }
    }
  };

  return Tools;
}();

var ApiServices = /*#__PURE__*/function () {
  function ApiServices() {
    this._apiUrl = Tools.GetLogitudeURL();
  }

  var _proto = ApiServices.prototype;

  _proto.getByFilters = function getByFilters(api, filters) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    apiURL = this.ConcatFiltersToURL(filters, apiURL);
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.get = function get(api) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.post = function post(api, date) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.post(apiURL, date, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.getTokenFromStorage = function getTokenFromStorage() {
    return window.localStorage.getItem("token") || '';
  };

  _proto.ConcatFiltersToURL = function ConcatFiltersToURL(filters, urlparameters) {
    var mykeys = Object.keys(filters);
    var addtionalFiltersValues = null;

    for (var i in mykeys) {
      var propName = mykeys[i];
      var propValue = filters[propName];
      var ignoreFilter = propName.indexOf("Operator") > 0 && propValue == "Equals" || propName == "AdditionalFilters";

      if (urlparameters != "?") {
        urlparameters = urlparameters.concat('&');
      }

      if (!ignoreFilter) {
        propValue = propValue ? encodeURIComponent(propValue) : '';
        urlparameters = urlparameters.concat(propName.concat('=').concat(propValue));
      }

      if (propName == "AdditionalFilters" && propValue.length > 0) {
        addtionalFiltersValues = JSON.stringify(propValue);
      }
    }

    if (addtionalFiltersValues) {
      urlparameters = urlparameters.concat("&AdditionalFilters=").concat(addtionalFiltersValues);
    }

    return urlparameters;
  };

  return ApiServices;
}();

var DashboardAnalyticsService = /*#__PURE__*/function () {
  function DashboardAnalyticsService() {
    this.controller = 'DashboardAnalytics';
    this._ApiServices = new ApiServices();
  }

  var _proto = DashboardAnalyticsService.prototype;

  _proto.getData = function getData(widget) {
    return this._ApiServices.post("/api/" + this.controller + "/PostGetDataAnalytic", widget);
  };

  _proto.getKpiData = function getKpiData(widget) {
    return this._ApiServices.post("/api/" + this.controller + "/PostGetKpiData", widget);
  };

  return DashboardAnalyticsService;
}();

var KpiChart = function KpiChart(props) {
  var _useState = React.useState(false),
      dataLoaded = _useState[0],
      setDataLoaded = _useState[1];

  var _useState2 = React.useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var widget = React.useRef();

  var _useState3 = React.useState(),
      data = _useState3[0],
      setData = _useState3[1];

  var _useState4 = React.useState(),
      arrowColorDirection = _useState4[0],
      setArrowColorDirection = _useState4[1];

  var _useState5 = React.useState(false),
      checkValuesValidity = _useState5[0],
      setCheckValuesValidity = _useState5[1];

  var _useState6 = React.useState(false),
      setVisibilityUnit = _useState6[1];
  React.useEffect(function () {
    widget.current = props.customChartProps.widget;
    setDataLoaded(false);
    setTimeout(function () {
      RefreshData();
    }, 500);
  }, []);

  var RefreshData = function RefreshData() {
    var dashboardAnalyticsService = new DashboardAnalyticsService();

    var postWidget = _extends({}, widget.current);

    postWidget.onChange = undefined;
    dashboardAnalyticsService.getKpiData(postWidget).then(function (result) {
      setData(result.data);
      setDataLoaded(true);
      setTimeOverTimeImage(result.data);
      checkValues(result.data);
      checkUnitVisible(result.data);
    }, function (error) {
      var _error$response, _error$response$data, _error$response2, _error$response2$data;

      console.log('error', error);
      if (error !== null && error !== void 0 && (_error$response = error.response) !== null && _error$response !== void 0 && (_error$response$data = _error$response.data) !== null && _error$response$data !== void 0 && _error$response$data.ErrorMessage) setError(error === null || error === void 0 ? void 0 : (_error$response2 = error.response) === null || _error$response2 === void 0 ? void 0 : (_error$response2$data = _error$response2.data) === null || _error$response2$data === void 0 ? void 0 : _error$response2$data.ErrorMessage);else setError(error.message);
      setDataLoaded(true);
    });
  };

  var kpiClick = function kpiClick() {
    var _widget$current, _widget$current2, _widget$current2$Widg;

    var measureFieldId;
    if (widget !== null && widget !== void 0 && (_widget$current = widget.current) !== null && _widget$current !== void 0 && _widget$current.WidgetMeasures) measureFieldId = widget === null || widget === void 0 ? void 0 : (_widget$current2 = widget.current) === null || _widget$current2 === void 0 ? void 0 : (_widget$current2$Widg = _widget$current2.WidgetMeasures[0]) === null || _widget$current2$Widg === void 0 ? void 0 : _widget$current2$Widg.MeasureFieldId;
    props.customChartProps.onSelectDataPoint({
      MeasureFieldId: measureFieldId,
      Widget: widget.current
    });
  };

  var setTimeOverTimeImage = function setTimeOverTimeImage(data) {
    var _widget$current3;

    if (!(widget !== null && widget !== void 0 && (_widget$current3 = widget.current) !== null && _widget$current3 !== void 0 && _widget$current3.TimeOverTime)) return;
    var ratio = data === null || data === void 0 ? void 0 : data.Ratio;
    if (!ratio) return;
    if (ratio >= 1) setArrowColorDirection(React__default.createElement("span", {
      className: "dl-kpi-arrow-pic dl-kpi-arrow-up"
    }));else if (ratio < 1) setArrowColorDirection(React__default.createElement("span", {
      className: "dl-kpi-arrow-pic dl-kpi-arrow-down"
    }));
  };

  var checkValues = function checkValues(data) {
    var _widget$current4, _widget$current5;

    setCheckValuesValidity(false);
    if (!(widget !== null && widget !== void 0 && (_widget$current4 = widget.current) !== null && _widget$current4 !== void 0 && _widget$current4.TimeOverTime)) return;
    if (widget !== null && widget !== void 0 && (_widget$current5 = widget.current) !== null && _widget$current5 !== void 0 && _widget$current5.TimeOverTime && ((data === null || data === void 0 ? void 0 : data.ComparisonValue) === 0 || (data === null || data === void 0 ? void 0 : data.ComparisonValue) === null) && ((data === null || data === void 0 ? void 0 : data.Value) === 0 || (data === null || data === void 0 ? void 0 : data.Value) === null)) return;
    setCheckValuesValidity(true);
  };

  var checkUnitVisible = function checkUnitVisible(data) {
    var _widget$current6;

    setVisibilityUnit(false);
    if (!(widget !== null && widget !== void 0 && (_widget$current6 = widget.current) !== null && _widget$current6 !== void 0 && _widget$current6.TimeOverTime) || (data === null || data === void 0 ? void 0 : data.ComparisonValue) == 0 || (data === null || data === void 0 ? void 0 : data.ComparisonValue) === null) return;
    setVisibilityUnit(true);
  };

  return !dataLoaded ? React__default.createElement("div", {
    className: 'dl-full-hight dl-flex-content-center spinner-custome'
  }, React__default.createElement(progressspinner.ProgressSpinner, {
    style: {
      width: '60px',
      height: '60px'
    },
    strokeWidth: "4",
    animationDuration: "2s"
  })) : !error ? React__default.createElement("div", {
    className: "kpIcontainer",
    onClick: kpiClick
  }, React__default.createElement("div", {
    className: "dl-kpi-same-line"
  }, React__default.createElement("div", {
    className: "dl-kpi-value dl-kpi-textTrimming"
  }, data === null || data === void 0 ? void 0 : data.Value), React__default.createElement("div", {
    className: "dl-kpi-unit"
  }, (data === null || data === void 0 ? void 0 : data.Value) != 0 && (data === null || data === void 0 ? void 0 : data.Unit)), checkValuesValidity ? React__default.createElement("div", {
    className: "dl-kpi-same-line dl-kpi-ratio"
  }, React__default.createElement("div", {
    className: "dl-kpi-margin"
  }, arrowColorDirection), React__default.createElement("div", null, data === null || data === void 0 ? void 0 : data.Ratio, " %")) : null)) : React__default.createElement("div", {
    className: "dl-flex-content-center dl-full-hight "
  }, React__default.createElement("div", {
    className: "dl-tooltip"
  }, React__default.createElement("img", {
    width: 100,
    src: "https://www.seekpng.com/png/full/334-3345964_error-icon-png.png"
  }), React__default.createElement("span", {
    className: "dl-tooltiptext"
  }, error)));
};

var CustomChart = function CustomChart(props) {
  var project = function project() {
    var _props$widget;

    switch ((_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.TypeCode) {
      case "kpi":
        return React__default.createElement(KpiChart, {
          customChartProps: props
        });

      default:
        return React__default.createElement("div", null, "Invalid Type");
    }
  };

  return React__default.createElement("div", {
    style: {
      height: '100%'
    }
  }, project());
};

function getCategoriesBasedDataSource(chartInfo, seriesMeasures) {
  if (!seriesMeasures || !seriesMeasures[0]) return {};
  return {
    chart: chartInfo,
    categories: buildCategories(seriesMeasures),
    dataset: buildDataSet(seriesMeasures)
  };
}
function getSimpleDataSource(chartInfo, seriesMeasures) {
  if (!seriesMeasures || !seriesMeasures[0]) return {};
  return {
    chart: chartInfo,
    data: buildDataSource(seriesMeasures)
  };
}

function buildDataSource(values) {
  var data = [];
  if (!values || !values[0]) return data;
  data = values[0].SeriesMeasureVulues.map(function (e, index) {
    var item = {
      value: e.Value,
      label: getTrimedLabelText(e.Label),
      id: {
        GroupById: e.GroupById,
        MeasureFieldId: values[0].MeasureFieldId
      },
      tooltext: e.Label + ' ,$dataValue ' + ', $percentValue',
      color: getSeriesPositionColor(index + 1)
    };
    return item;
  });
  return data;
}

function getTrimedLabelText(label) {
  if (!label || label.length <= 20) return label;
  return label.substring(0, 17) + "...";
}

function buildDataSet(seriesMeasures) {
  var dataSet = [];
  var seriesPosition = 1;
  seriesMeasures.forEach(function (seriesMeasure) {
    var datas = seriesMeasure.SeriesMeasureVulues.map(function (e) {
      return {
        value: e.Value,
        id: {
          GroupById: e.GroupById,
          MeasureFieldId: seriesMeasure.MeasureFieldId
        }
      };
    });
    dataSet.push({
      data: datas,
      seriesname: seriesMeasure.Name,
      color: getSeriesPositionColor(seriesPosition)
    });
    seriesPosition++;
  });
  return dataSet;
}

function buildCategories(seriesMeasures) {
  var categories = seriesMeasures[0].SeriesMeasureVulues.map(function (e) {
    return {
      label: e.Label
    };
  });
  var result = [];
  result.push({
    category: categories
  });
  return result;
}

var mainYellowColor = "#F6CF33";
var mainRedColor = "#EE5F77";
var mainGreenColor = "#4AC76F";
var mainTurquoiseColor = "#32C7C7";
var mainBlueColor = "#369CFB";
var mainPurpleColor = "#935BE0";
var mainOrangeColor = "#FAAD14";

var defautFontSize = "11";
var defautFont = "Manrope";
function BuildFusionChartObject(seriesMeasures, widget) {
  handelNullLabels(seriesMeasures);

  switch (widget === null || widget === void 0 ? void 0 : widget.TypeCode) {
    case 'bar':
      return getBarObject(seriesMeasures);

    case 'line':
      return getLineObject(seriesMeasures);

    case 'pie':
      return getPieObject(seriesMeasures);

    case 'donut':
      return getDonutObject(seriesMeasures);

    default:
      return {};
  }
}

function handelNullLabels(seriesMeasures) {
  seriesMeasures.forEach(function (element) {
    element.SeriesMeasureVulues.forEach(function (value) {
      if (!value.Label || value.Label == '') value.Label = 'Not defined';
    });
  });
}

function getBarObject(seriesMeasures, widget) {
  var chart = getDefaultChartobject();
  chart.type = "scrollbar2d";
  var chartInfo = getDefaultChartInfo();
  chartInfo.scrollHeight = "5";
  chartInfo.scrollWidth = "5";
  chartInfo.scrollPadding = "8";
  chartInfo.flatScrollBars = "1";
  chartInfo.showPercentValues = "1";
  chartInfo.showLegend = (seriesMeasures === null || seriesMeasures === void 0 ? void 0 : seriesMeasures.length) > 1 ? "1" : "0";
  chartInfo.legendItemFont = defautFont;
  chartInfo.legendItemFontSize = defautFontSize;
  chartInfo.divLineDashed = "1";
  chartInfo.divLineDashLen = "7";
  chart.dataSource = getCategoriesBasedDataSource(chartInfo, seriesMeasures);
  return chart;
}

function getLineObject(seriesMeasures, widget) {
  var chart = getDefaultChartobject();
  chart.type = "msspline";
  var chartInfo = getDefaultChartInfo();
  chartInfo.scrollHeight = "5";
  chartInfo.scrollWidth = "5";
  chartInfo.scrollPadding = "8";
  chartInfo.flatScrollBars = "1";
  chartInfo.showPercentValues = "1";
  chartInfo.showLegend = (seriesMeasures === null || seriesMeasures === void 0 ? void 0 : seriesMeasures.length) > 1 ? "1" : "0";
  chartInfo.legendItemFont = defautFont;
  chartInfo.legendItemFontSize = defautFontSize;
  chartInfo.divLineDashed = "1";
  chartInfo.divLineDashLen = "7";
  chart.dataSource = getCategoriesBasedDataSource(chartInfo, seriesMeasures);
  return chart;
}

function getDonutObject(seriesMeasures, widget) {
  var chart = getDefaultChartobject();
  chart.type = "doughnut2d";
  var chartInfo = getDefaultChartInfo();
  chartInfo.showPercentValues = "0";
  chartInfo.showValues = "0";
  chartInfo.showLegend = "0";
  chartInfo.legendCaptionFontSize = defautFontSize;
  chartInfo.legendCaptionFont = defautFont;
  chart.dataSource = getSimpleDataSource(chartInfo, seriesMeasures);
  return chart;
}

function getPieObject(seriesMeasures, widget) {
  var chart = getDefaultChartobject();
  chart.type = "pie2d";
  var chartInfo = getDefaultChartInfo();
  chartInfo.showPercentValues = "0";
  chartInfo.showValues = "0";
  chartInfo.showLegend = "0";
  chartInfo.legendCaptionFontSize = defautFontSize;
  chartInfo.legendCaptionFont = defautFont;
  chartInfo.labelFontSize = defautFontSize;
  chartInfo.labelFont = defautFont;
  chart.dataSource = getSimpleDataSource(chartInfo, seriesMeasures);
  return chart;
}

function getDefaultChartobject() {
  var chart = {};
  chart.type = "column2d";
  chart.width = "100%";
  chart.height = "100%";
  chart.dataFormat = "json";
  return chart;
}

function getDefaultChartInfo() {
  var chart = {};
  chart.theme = "fusion";
  chart.baseFont = defautFont;
  chart.baseFontSize = defautFontSize;
  chart.enableSlicing = "0";
  chart.enableRotation = "0";
  chart.chartLeftMargin = "20";
  chart.chartTopMargin = "20";
  chart.chartRightMargin = "20";
  chart.chartBottomMargin = "20";
  return chart;
}
function getSeriesPositionColor(position) {
  switch (position) {
    case 1:
      return mainBlueColor;

    case 2:
      return mainGreenColor;

    case 3:
      return mainYellowColor;

    case 4:
      return mainTurquoiseColor;

    case 5:
      return mainPurpleColor;

    case 6:
      return mainOrangeColor;

    case 7:
      return mainRedColor;

    default:
      return null;
  }
}

ReactFC.fcRoot(FusionCharts, Charts, FusionTheme);
FusionCharts.options['license']({
  key: 'prD4C-8eiA7A3A3C7E6G4B4A3J4C7B2D3D2nyqE1C3fd1npaE4D4tlA-21D7E4F4F1F1E1F4F1A10A8C2C5F5E2F2D1hwqD1B5D1aG4A19A32twbC6D3G4lhJ-7A9C11A5B-13ddA2I3A1B9B3D7A2B4G2H3H1F-7smC8B2XB4cetB8A7A5mxD3SG4F2tvgB2A3B2E4C3I3C7B3A4A3A2D3D2G4J-7==',
  creditLabel: false
});

var FusionChart = function FusionChart(props) {
  var _useState = React.useState(false),
      dataLoaded = _useState[0],
      setDataLoaded = _useState[1];

  var _useState2 = React.useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var widget = React.useRef();

  var _useState3 = React.useState({}),
      args = _useState3[0],
      setArgs = _useState3[1];

  var _useState4 = React.useState({}),
      fChart = _useState4[0],
      setFchart = _useState4[1];

  var id = (Math.random() + 1).toString(36).substring(7);

  var _useState5 = React.useState(),
      widgetWidth = _useState5[0],
      setWidgetWidth = _useState5[1];

  var _useState6 = React.useState(),
      widgetHeight = _useState6[0],
      setWidgetHeight = _useState6[1];

  React.useEffect(function () {
    widget.current = props.widget;
    setTimeout(function () {
      RefreshData();
    }, 500);
  }, []);

  var RefreshData = function RefreshData() {
    var dashboardAnalyticsService = new DashboardAnalyticsService();

    var postWidget = _extends({}, widget.current);

    postWidget.onChange = undefined;
    dashboardAnalyticsService.getData(postWidget).then(function (result) {
      var chart = BuildFusionChartObject(result.data, widget.current);
      setArgs(chart);
      setDataLoaded(true);
      if (widgetHeight && widgetWidth && fChart) fChart.resizeTo(widgetWidth, widgetHeight);
    }, function (error) {
      var _error$response, _error$response$data, _error$response2, _error$response2$data;

      console.log('error', error);
      if (error !== null && error !== void 0 && (_error$response = error.response) !== null && _error$response !== void 0 && (_error$response$data = _error$response.data) !== null && _error$response$data !== void 0 && _error$response$data.ErrorMessage) setError(error === null || error === void 0 ? void 0 : (_error$response2 = error.response) === null || _error$response2 === void 0 ? void 0 : (_error$response2$data = _error$response2.data) === null || _error$response2$data === void 0 ? void 0 : _error$response2$data.ErrorMessage);else setError(error.message);
      setDataLoaded(true);
    });
  };

  var dataplotClick = function dataplotClick(eventObj, dataObj) {
    props.onSelectDataPoint({
      GroupById: dataObj.id.groupbyid,
      MeasureFieldId: dataObj.id.measurefieldid,
      Widget: widget.current
    });
  };

  var renderComplete = function renderComplete(chart) {
    setFchart(chart);
  };

  var _useResizeObserver = useResizeObserver({
    onResize: function onResize(_ref) {
      var width = _ref.width,
          height = _ref.height;
      setWidgetWidth(width);
      setWidgetHeight(height);
      fChart.resizeTo(width, height);
    }
  }),
      ref = _useResizeObserver.ref;

  return !dataLoaded ? React__default.createElement("div", {
    className: 'dl-full-hight dl-flex-content-center spinner-custome'
  }, React__default.createElement(progressspinner.ProgressSpinner, {
    style: {
      width: '60px',
      height: '60px'
    },
    strokeWidth: "4",
    animationDuration: "2s"
  })) : !error ? React__default.createElement("div", {
    className: 'db-fc-container',
    ref: ref,
    id: id
  }, React__default.createElement(ReactFC, Object.assign({}, args, {
    "fcEvent-dataplotClick": dataplotClick,
    onRender: renderComplete
  }))) : React__default.createElement("div", {
    className: "dl-flex-content-center dl-full-hight "
  }, React__default.createElement("div", {
    className: "dl-tooltip"
  }, React__default.createElement("img", {
    width: 100,
    src: "https://www.seekpng.com/png/full/334-3345964_error-icon-png.png"
  }), React__default.createElement("span", {
    className: "dl-tooltiptext"
  }, error)));
};

var WidgetCard = function WidgetCard(props, state) {
  var _widget$current2, _widget$current3;

  var moreBtnToggle = React.useRef(null);
  var widget = React.useRef();

  var _useState = React.useState(false),
      isLoading = _useState[0],
      setIsLoading = _useState[1];

  var editWidget = function editWidget() {
    var _moreBtnToggle$curren;

    (_moreBtnToggle$curren = moreBtnToggle.current) === null || _moreBtnToggle$curren === void 0 ? void 0 : _moreBtnToggle$curren.hide();
    props.editBtnClicked(widget.current);
  };

  React.useEffect(function () {
    var _props$dataBinding;

    widget.current = props.widget;
    (_props$dataBinding = props.dataBinding) === null || _props$dataBinding === void 0 ? void 0 : _props$dataBinding.onEditWidget.subscribe(function (e) {
      var _widget$current;

      if ((e === null || e === void 0 ? void 0 : e.key) != ((_widget$current = widget.current) === null || _widget$current === void 0 ? void 0 : _widget$current.key)) return;
      setIsLoading(true);
      widget.current = _extends({}, e);
      setIsLoading(false);
    });
  }, []);
  return React__default.createElement("div", {
    className: "panel",
    key: props.el.i,
    style: {
      cursor: props.isInEditMode ? 'move' : 'default'
    }
  }, React__default.createElement("header", null, React__default.createElement(tooltip.Tooltip, {
    target: ".h-tool-tip"
  }), React__default.createElement("h1", {
    "data-pr-tooltip": (_widget$current2 = widget.current) === null || _widget$current2 === void 0 ? void 0 : _widget$current2.Title,
    "data-pr-position": "top",
    className: "h-tool-tip"
  }, (_widget$current3 = widget.current) === null || _widget$current3 === void 0 ? void 0 : _widget$current3.Title), props.isInEditMode ? React__default.createElement(button.Button, {
    icon: "pi pi-ellipsis-v",
    className: "p-button-rounded p-button-text",
    onClick: function onClick(e) {
      var _moreBtnToggle$curren2;

      return (_moreBtnToggle$curren2 = moreBtnToggle.current) === null || _moreBtnToggle$curren2 === void 0 ? void 0 : _moreBtnToggle$curren2.toggle(e);
    },
    style: {
      color: "#292D30"
    }
  }) : null, React__default.createElement(overlaypanel.OverlayPanel, {
    ref: moreBtnToggle,
    className: "buttons-overlay"
  }, React__default.createElement("div", {
    className: "buttons-list"
  }, React__default.createElement("div", {
    onClick: editWidget
  }, " Edit "), React__default.createElement("div", {
    onClick: function onClick() {
      var _props$widget;

      return props.deleteBtnClicked((_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.key);
    }
  }, "Remove")))), React__default.createElement("div", {
    className: "dl-line"
  }), React__default.createElement("div", {
    className: "dl-dashboard-widget"
  }, " ", GetChartComponent(), " "));

  function GetChartComponent() {
    var _widget$current4, _widget$current5;

    if (isLoading || !((_widget$current4 = widget.current) !== null && _widget$current4 !== void 0 && _widget$current4.TypeCode)) return null;
    if (((_widget$current5 = widget.current) === null || _widget$current5 === void 0 ? void 0 : _widget$current5.TypeCode) == "kpi") return React__default.createElement(CustomChart, {
      dataBinding: props.dataBinding,
      widget: widget.current,
      widgetRef: props.widgetRef,
      onSelectDataPoint: props.onSelectDataPoint
    });
    return React__default.createElement(FusionChart, {
      dataBinding: props.dataBinding,
      widget: widget.current,
      widgetRef: props.widgetRef,
      onSelectDataPoint: props.onSelectDataPoint
    });
  }
};

function deepClone(obj) {
  return JSON.parse(JSON.stringify(obj));
}

var ResponsiveReactGridLayout = reactGridLayout.WidthProvider(reactGridLayout.Responsive);

var DashboardDesigner = function DashboardDesigner(props) {
  var array12 = Array.from({
    length: 12
  }).fill(null);
  var minimumPlaceholderRowsCount = 12;

  var _useState = React.useState({
    lg: []
  }),
      layouts = _useState[0],
      setLayouts = _useState[1];

  var _useState2 = React.useState(Array.from({
    length: minimumPlaceholderRowsCount
  }).fill(null)),
      placeholderRowsArray = _useState2[0],
      setplaceholderRowsArray = _useState2[1];

  var _useState3 = React.useState(undefined),
      dateFilter = _useState3[0];

  var _useState4 = React.useState(false),
      isInEditMode = _useState4[0],
      setisInEditMode = _useState4[1];

  var widgetsDictionaryRef = React.useRef({});

  var _useState5 = React.useState({
    lg: []
  }),
      widgets = _useState5[0],
      setWidgets = _useState5[1];

  var gridLayoutComponent = React.useRef(null);
  var entered = React.useRef(false);
  React.useEffect(function () {
    FillLayout(props.Widgetlayouts);
  }, [props.Widgetlayouts]);

  var FillLayout = function FillLayout(dashboardLayouts) {
    var clone = deepClone(dashboardLayouts);
    var layout = createLayout(clone);
    FillWidgetDictionary(clone);
    setWidgets(clone);
    setLayouts(layout);
    UpdatePlaceholderDimensions(layout);
  };

  var FillWidgetDictionary = function FillWidgetDictionary(clone) {
    for (var _iterator = _createForOfIteratorHelperLoose(clone.lg), _step; !(_step = _iterator()).done;) {
      var item = _step.value;
      widgetsDictionaryRef.current[item.key] = item;
    }
  };

  var createLayout = function createLayout(dashboardLayouts) {
    var layout = {
      lg: []
    };
    dashboardLayouts.lg.map(function (w) {
      return w.Layout;
    }).forEach(function (e) {
      layout.lg.push(e);
    });
    return layout;
  };

  React.useEffect(function () {
    setisInEditMode(props.editMode);
  }, [props.editMode]);

  function onLayoutChange(layout, changedLayouts) {
    UpdateWidget(changedLayouts);
    setLayouts(changedLayouts);
    UpdatePlaceholderDimensions(changedLayouts);

    if (entered.current == false) {
      entered.current = true;
      return;
    }

    props.onLayoutChange(changedLayouts);
  }

  function UpdateWidget(changedLayouts) {
    for (var _iterator2 = _createForOfIteratorHelperLoose(changedLayouts.lg), _step2; !(_step2 = _iterator2()).done;) {
      var item = _step2.value;

      if (widgetsDictionaryRef.current[item.i]) {
        widgetsDictionaryRef.current[item.i].Layout = item;
      }
    }
  }

  function deletePanel(id) {
    var newLayouts = {
      lg: layouts.lg.filter(function (e) {
        return e.i != id;
      })
    };
    setLayouts(newLayouts);
    var newWidgets = {
      lg: widgets.lg.filter(function (e) {
        return e.key != id;
      })
    };
    FillWidgetDictionary(newWidgets);
    setWidgets(newWidgets);
    props.onLayoutChange(newLayouts);
  }

  function editWidget(widget) {
    widget.ChangeSetOp = 'Update';
    props.openEditWidget(widget);
  }

  function UpdatePlaceholderDimensions(layouts) {
    if (!layouts) return;
    var max = minimumPlaceholderRowsCount;

    for (var _iterator3 = _createForOfIteratorHelperLoose(layouts['lg']), _step3; !(_step3 = _iterator3()).done;) {
      var layout = _step3.value;
      if (layout.y + layout.h > max) max = layout.y + layout.h;
    }

    var newPlaceholderRows = max + 2;
    newPlaceholderRows = newPlaceholderRows < minimumPlaceholderRowsCount ? minimumPlaceholderRowsCount : newPlaceholderRows;
    setplaceholderRowsArray(Array.from({
      length: newPlaceholderRows
    }).fill(null));
  }

  return React__default.createElement("div", {
    className: "dl-full-hight-scroll"
  }, React__default.createElement("div", {
    className: "dl-box"
  }, React__default.createElement("div", {
    className: "dl-row dl-content"
  }, React__default.createElement("div", {
    className: "dl-grid-container"
  }, React__default.createElement("div", {
    className: "dl-grid dl-grid--bordered"
  }, isInEditMode ? placeholderRowsArray.map(function (e, i) {
    return array12.map(function (e, i) {
      return React__default.createElement("div", {
        key: i,
        style: {
          height: layoutGridProps.rowHeight
        }
      });
    });
  }) : null), React__default.createElement(ResponsiveReactGridLayout, Object.assign({
    ref: gridLayoutComponent
  }, layoutGridProps, {
    layouts: layouts,
    compactType: "vertical",
    isDraggable: isInEditMode,
    isResizable: isInEditMode,
    onWidthChange: function onWidthChange() {},
    onLayoutChange: onLayoutChange
  }), widgets.lg.map(function (widget) {
    var _widget$Layout, _widget$Layout2;

    return React__default.createElement("div", {
      key: (_widget$Layout = widget.Layout) === null || _widget$Layout === void 0 ? void 0 : _widget$Layout.i
    }, React__default.createElement(WidgetCard, {
      isInEditMode: isInEditMode,
      key: (_widget$Layout2 = widget.Layout) === null || _widget$Layout2 === void 0 ? void 0 : _widget$Layout2.i,
      widget: widget,
      widgetRef: widgetsDictionaryRef.current[widget.key],
      el: widget,
      dataBinding: props.dataBinding,
      dateFilter: dateFilter,
      editBtnClicked: editWidget,
      deleteBtnClicked: deletePanel,
      onSelectDataPoint: props.onSelectDataPoint
    }));
  }))))));
};

var layoutGridProps = {
  rowHeight: 50,
  className: "layout",
  cols: {
    lg: 12,
    md: 6,
    sm: 2,
    xs: 1,
    xxs: 1
  },
  useCSSTransforms: true
};

var Dashboard = function Dashboard(props) {
  var _props$token;

  var Widgetlayouts = React.useRef({
    lg: []
  });

  var _useState = React.useState({
    lg: []
  }),
      widgetlayoutsState = _useState[0],
      setWidgetlayoutsState = _useState[1];

  var _useState2 = React.useState(false),
      isInEditMode = _useState2[0],
      setIsInEditMode = _useState2[1];

  React.useEffect(function () {
    props.dataBinding.onGetLayouts.subscribe(function (layouts) {
      Widgetlayouts.current = layouts;
      setWidgetlayoutsState(deepClone(Widgetlayouts.current));
    });
    props.dataBinding.isOnEditLayout.subscribe(function (e) {
      setIsInEditMode(e);
    });
    props.dataBinding.onAddWidget.subscribe(function (w) {
      Widgetlayouts.current.lg.push(w);
      setWidgetlayoutsState(deepClone(Widgetlayouts.current));
    });
  }, []);
  if ((props === null || props === void 0 ? void 0 : (_props$token = props.token) === null || _props$token === void 0 ? void 0 : _props$token.length) > 0) localStorage.setItem("token", props === null || props === void 0 ? void 0 : props.token);

  var updateWidgets = function updateWidgets(layouts) {
    var layoutsDic = {};
    Object.keys(layouts).forEach(function (sizeType) {
      if (layouts[sizeType].length > 0) {
        layouts[sizeType].map(function (layout) {
          layoutsDic[layout.i] = layout;
        });
        return;
      }
    });
    var newWidgetlayouts = [];
    Widgetlayouts.current.lg.forEach(function (widget) {
      if (layoutsDic[widget.key]) {
        widget.StartPotistion = layoutsDic[widget.key].x + "," + layoutsDic[widget.key].y;
        widget.EndPosition = layoutsDic[widget.key].w + "," + layoutsDic[widget.key].h;
        widget.Layout = layoutsDic[widget.key];
        newWidgetlayouts.push(widget);
      }
    });
    Widgetlayouts.current = {
      lg: newWidgetlayouts
    };
    props.onChangeLayouts(Widgetlayouts.current);
  };

  return React.createElement("div", {
    className: 'dl-full-hight'
  }, React.createElement("div", {
    className: 'dl-dashboard-body'
  }, React.createElement(DashboardDesigner, {
    onSelectDataPoint: props.onSelectDataPoint,
    Widgetlayouts: widgetlayoutsState,
    dataBinding: props.dataBinding,
    editMode: isInEditMode,
    onLayoutChange: updateWidgets,
    openEditWidget: function openEditWidget(widget) {
      return props.openEditWidget(widget);
    }
  })));
};

module.exports = Dashboard;
//# sourceMappingURL=index.js.map
